@@ -32,7 +32,7 @@ class DESnookerMove(RedBlueMove):
         Ns = len(s)
         Nc = list(map(len, c))
         ndim = s.shape[1]
-        q = np.empty((Ns, ndim), dtype=np.float64)
+        q = np.empty_like(s)
         metropolis = np.empty(Ns, dtype=np.float64)
         for i in range(Ns):
             w = np.array([c[j][random.randint(Nc[j])] for j in range(3)])
